@@ -108,13 +108,12 @@ class UTextResult(unittest.TextTestResult):
             # For unittest framework where getDescription may return None.
             item_title = self.getDescription(test)
         self.item_title_print = " * q%i.%i) %s" % (UTextResult.number + 1, self.testsRun, item_title)
-        if self.show_progress_bar or True:
-            estimated_time = test.__class__._cache.get(((name, test._testMethodName), 'time'), 100) if hasattr(test.__class__, '_cache') else 4
-            self.cc = ActiveProgress(t=estimated_time, title=self.item_title_print, show_progress_bar=self.show_progress_bar, file=sys.stdout)
-        else:
-            print(self.item_title_print + ('.' * max(0, self.nL - 4 - len(self.item_title_print))), end="")
+        # if self.show_progress_bar or True:
+        estimated_time = test.__class__._cache.get(((name, test._testMethodName), 'time'), 100) if hasattr(test.__class__, '_cache') else 4
+        self.cc = ActiveProgress(t=estimated_time, title=self.item_title_print, show_progress_bar=self.show_progress_bar)
+        # else:
+        #     print(self.item_title_print + ('.' * max(0, self.nL - 4 - len(self.item_title_print))), end="")
         self._test = test
-
         # if not self.unmute:
         self._stdout = sys.stdout # Redundant. remove later.
         from unitgrade.utils import Logger
@@ -125,9 +124,7 @@ class UTextResult(unittest.TextTestResult):
         buff = sys.stdout.log
         sys.stdout = self._stdout # redundant.
         buff.close()
-
         from unitgrade.utils import Logger
-
         super().stopTest(test)
 
     def _setupStdout(self):
@@ -138,9 +135,10 @@ class UTextResult(unittest.TextTestResult):
             else:
                 q_title_print = "<unnamed test. See unitgrade.framework.py>"
 
-            cc = ActiveProgress(t=self.setUpClass_time, title=q_title_print, show_progress_bar=self.show_progress_bar)
+            cc = ActiveProgress(t=self.setUpClass_time, title=q_title_print, show_progress_bar=self.show_progress_bar, mute_stdout=not self.unmute)
             self.cc = cc
 
+
     def _restoreStdout(self):  # Used when setting up the test.
         if self._previousTestClass is None:
             q_time = self.cc.terminate()
