@@ -305,13 +305,14 @@ def load_token(file_in):
 ## Key/value store related.
 class DKPupDB:
     """ This key/value store store artifacts (associated with a specific question) in a dictionary. """
-    def __init__(self, artifact_file, use_pupdb=False):
+    def __init__(self, artifact_file, use_pupdb=False, register_ephemeral=False):
         # Make a double-headed disk cache thingy.
         self.dk = Cache(os.path.dirname(artifact_file)) # Start in this directory.
         self.name_ = os.path.basename(artifact_file[:-5])
         if self.name_ not in self.dk:
             self.dk[self.name_] = dict()
         self.use_pupdb = use_pupdb
+        self.register_ephemeral = register_ephemeral
         if self.use_pupdb:
             from pupdb.core import PupDB
             self.db_ = PupDB(artifact_file)
@@ -323,6 +324,7 @@ class DKPupDB:
             d = self.dk[self.name_]
             d[key] = value
             self.dk[self.name_] = d
+            self.dk.set(key=np.random.randint(0, high=1e8), value=(key,value), tag="ephemeral")
             self.dk[self.name_ + "-updated"] = True
 
     def __getitem__(self, item):
